"use client";

import { useState, useEffect } from "react";
import { useSearchParams } from "next/navigation";
import axios from "@/services/APIservices";
import AdminLayout from "@/components/admin/adminLayout";
import LandownerInquery from "@/components/admin/admin_sidebar/LandownerInquiry/LandownerInquiry";
import AgentInquiry from "@/components/admin/admin_sidebar/AgentInquiry/AgentInquiry";
import DeveloperInquiry from "@/components/admin/admin_sidebar/DeveloperInquiry/DeveloperInquiry";

export default function PublicInquiryPage() {
  const searchParams = useSearchParams();

  // State to store API data
  const [agentinquiryCount, setAgentinquiryCount] = useState(0);  
  const [landownerinquiryCount, setLandownerinquiryCount] = useState(0); 
  const [developerinquiryCount, setDeveloperinquiryCount] = useState(0); 
  const [agentInqData, setAgentInqData] = useState(null);
  const [landownerInquiries, setLandownerInquiries] = useState(null);
  const [developerInquiries, setDeveloperInquiries] = useState(null);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  // Mapping of view keys to components
  const viewComponents = {
    agentInquiry: AgentInquiry,
    landownerInquiry: LandownerInquery,
    developerInquiry: DeveloperInquiry,
  };

  // Extract view from URL or default to 'agentInquiry'
  const currentView = searchParams.get("view") || "agentInquiry";

  // Dynamically select the component based on current view
  const SelectedComponent = viewComponents[currentView] || AgentInquiry;

  const fetchUserAgentData = async () => {
    try {
      const response = await axios.get("/api/admin-inquiry");  

      if (response.data.success) {
        setAgentinquiryCount(response.data.agentinquiryCount);   
        setLandownerinquiryCount(response.data.landownerinquiryCount);
        setDeveloperinquiryCount(response.data.developerinquiryCount); 
        setAgentInqData(response.data.agentInqData);
        setLandownerInquiries(response.data.landownerInquiries);
        setDeveloperInquiries(response.data.developerInquiries);
        setError(null); // Clear any previous errors
      } else {
        setError(response.data.message || "Failed to fetch data.");
      }
    } catch (err) {
      setError(err.message || "An error occurred while fetching data.");
    } finally {
      setLoading(false); // Stop loading after fetch
    }
  };

  useEffect(() => {
    // Fetch data initially
    fetchUserAgentData();

    // Set up polling every 5 seconds
    const pollingInterval = setInterval(() => {
      fetchUserAgentData();
    }, 2000); // Adjust the interval as needed

    // Clean up the interval on component unmount
    return () => clearInterval(pollingInterval);
  }, []); // Empty dependency array ensures this runs only once

  if (loading) {
    return (
      <AdminLayout>
        <div>Loading...</div>
      </AdminLayout>
    );
  }

  if (error) {
    return (
      <AdminLayout>
        <div>Error: {error}</div>
      </AdminLayout>
    );
  }

  return (
    <AdminLayout>
      {/* Render the selected component and pass down API data */}
      <SelectedComponent

        //agent
        agentinquiryCount={agentinquiryCount}  
        agentInqData={agentInqData}
        //landowner
        landownerinquiryCount={landownerinquiryCount}   
        landownerInquiries={landownerInquiries}
        //developer
        developerinquiryCount={developerinquiryCount}
        developerInquiries={developerInquiries}
      />
    </AdminLayout>
  );
}